You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cordova.apache.org by an...@apache.org on 2016/08/09 09:31:30 UTC

[1/6] cordova-lib git commit: CB-11589: Fix missing plugin files after restore

Repository: cordova-lib
Updated Branches:
  refs/heads/6.3.x 09ab5bbc7 -> a2736f594


CB-11589: Fix missing plugin files after restore

 This closes #464


Project: http://git-wip-us.apache.org/repos/asf/cordova-lib/repo
Commit: http://git-wip-us.apache.org/repos/asf/cordova-lib/commit/63420225
Tree: http://git-wip-us.apache.org/repos/asf/cordova-lib/tree/63420225
Diff: http://git-wip-us.apache.org/repos/asf/cordova-lib/diff/63420225

Branch: refs/heads/6.3.x
Commit: 634202255d1c0e86ed8845a673818e5add7d7b1b
Parents: 09ab5bb
Author: Darryl Pogue <da...@ayogo.com>
Authored: Fri Jul 15 11:23:27 2016 -0700
Committer: Vladimir Kotikov <v-...@microsoft.com>
Committed: Mon Aug 8 10:45:07 2016 +0300

----------------------------------------------------------------------
 cordova-lib/src/cordova/platform.js | 24 ++++++++++++++----------
 cordova-lib/src/cordova/prepare.js  |  2 +-
 2 files changed, 15 insertions(+), 11 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cordova-lib/blob/63420225/cordova-lib/src/cordova/platform.js
----------------------------------------------------------------------
diff --git a/cordova-lib/src/cordova/prepare.js b/cordova-lib/src/cordova/prepare.js
index ff4f119..00d50ad 100644
--- a/cordova-lib/src/cordova/prepare.js
+++ b/cordova-lib/src/cordova/prepare.js
@@ -43,7 +43,7 @@ function prepare(options) {
         var hooksRunner = new HooksRunner(projectRoot);
         return hooksRunner.fire('before_prepare', options)
         .then(function(){
-            return restore.installPlatformsFromConfigXML(options.platforms, { searchpath : options.searchpath, fetch : options.fetch, save : options.save });
+            return restore.installPlatformsFromConfigXML(options.platforms, { searchpath : options.searchpath, fetch : options.fetch, restoring : true });
         })
         .then(function(){
             options = cordova_util.preProcessOptions(options);


---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@cordova.apache.org
For additional commands, e-mail: commits-help@cordova.apache.org


[4/6] cordova-lib git commit: CB-11493: Add cordova emulate option to skip prepare

Posted by an...@apache.org.
CB-11493: Add cordova emulate option to skip prepare

 This closes #459


Project: http://git-wip-us.apache.org/repos/asf/cordova-lib/repo
Commit: http://git-wip-us.apache.org/repos/asf/cordova-lib/commit/e4f30cee
Tree: http://git-wip-us.apache.org/repos/asf/cordova-lib/tree/e4f30cee
Diff: http://git-wip-us.apache.org/repos/asf/cordova-lib/diff/e4f30cee

Branch: refs/heads/6.3.x
Commit: e4f30ceefd39e646d0513c50a1d17900995a4f50
Parents: b5dc35b
Author: gruppjo <jo...@web.de>
Authored: Mon Jun 27 16:50:02 2016 +0200
Committer: Vladimir Kotikov <v-...@microsoft.com>
Committed: Mon Aug 8 10:46:01 2016 +0300

----------------------------------------------------------------------
 cordova-lib/src/cordova/emulate.js | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cordova-lib/blob/e4f30cee/cordova-lib/src/cordova/emulate.js
----------------------------------------------------------------------
diff --git a/cordova-lib/src/cordova/emulate.js b/cordova-lib/src/cordova/emulate.js
index b0b61aa..642e55c 100644
--- a/cordova-lib/src/cordova/emulate.js
+++ b/cordova-lib/src/cordova/emulate.js
@@ -35,8 +35,10 @@ module.exports = function emulate(options) {
         var hooksRunner = new HooksRunner(projectRoot);
         return hooksRunner.fire('before_emulate', options)
         .then(function() {
-            // Run a prepare first!
-            return require('./cordova').raw.prepare(options);
+            if (!options.options.noprepare) {
+                // Run a prepare first!
+                return require('./cordova').raw.prepare(options);
+            }
         }).then(function() {
             // Deploy in parallel (output gets intermixed though...)
             return Q.all(options.platforms.map(function(platform) {


---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@cordova.apache.org
For additional commands, e-mail: commits-help@cordova.apache.org


[3/6] cordova-lib git commit: CB-11194 Defer creating of libDir folder until something actually requests it

Posted by an...@apache.org.
CB-11194 Defer creating of libDir folder until something actually requests it

This closes #462


Project: http://git-wip-us.apache.org/repos/asf/cordova-lib/repo
Commit: http://git-wip-us.apache.org/repos/asf/cordova-lib/commit/647852e5
Tree: http://git-wip-us.apache.org/repos/asf/cordova-lib/tree/647852e5
Diff: http://git-wip-us.apache.org/repos/asf/cordova-lib/diff/647852e5

Branch: refs/heads/6.3.x
Commit: 647852e5e48f779cc99c91b470d35b177644c342
Parents: e4f30ce
Author: Jesse MacFadyen <pu...@gmail.com>
Authored: Fri Jul 1 16:35:53 2016 -0700
Committer: Vladimir Kotikov <v-...@microsoft.com>
Committed: Mon Aug 8 10:46:01 2016 +0300

----------------------------------------------------------------------
 cordova-lib/src/cordova/util.js | 15 +++++++++++++--
 1 file changed, 13 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cordova-lib/blob/647852e5/cordova-lib/src/cordova/util.js
----------------------------------------------------------------------
diff --git a/cordova-lib/src/cordova/util.js b/cordova-lib/src/cordova/util.js
index 1bc227e..e617e08 100644
--- a/cordova-lib/src/cordova/util.js
+++ b/cordova-lib/src/cordova/util.js
@@ -38,11 +38,22 @@ if (!global_config_path) {
 var origCwd = null;
 
 var lib_path = path.join(global_config_path, 'lib');
-shell.mkdir('-p', lib_path);
+
 
 exports.binname = 'cordova';
 exports.globalConfig = global_config_path;
-exports.libDirectory = lib_path;
+
+// defer defining libDirectory on exports so we don't create it if 
+// someone simply requires this module
+Object.defineProperty(exports,'libDirectory', {
+        configurable: true,
+        get: function () {
+            shell.mkdir('-p', lib_path);
+            exports.libDirectory = lib_path;
+        return lib_path;
+    }
+});
+
 addModuleProperty(module, 'plugin_parser', './plugin_parser');
 
 exports.isCordova = isCordova;


---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@cordova.apache.org
For additional commands, e-mail: commits-help@cordova.apache.org


[5/6] cordova-lib git commit: CB-11652 Update run and emulate to skip build

Posted by an...@apache.org.
CB-11652 Update run and emulate to skip build

We need to add this conditional logic to cordova's `run` and
`emulate` methods to skip build when `--nobuild` option is
specified. CLI previously has delegated this logic to platform's
`run` method but since introducing `before_deploy` hook we call
platform's `build` and `run` separately and so we need to handle
this option in CLI


Project: http://git-wip-us.apache.org/repos/asf/cordova-lib/repo
Commit: http://git-wip-us.apache.org/repos/asf/cordova-lib/commit/9b023d1b
Tree: http://git-wip-us.apache.org/repos/asf/cordova-lib/tree/9b023d1b
Diff: http://git-wip-us.apache.org/repos/asf/cordova-lib/diff/9b023d1b

Branch: refs/heads/6.3.x
Commit: 9b023d1bdd4c26bb94da751d3bc270dab3ae1ceb
Parents: 647852e
Author: Vladimir Kotikov <v-...@microsoft.com>
Authored: Tue Aug 2 15:08:24 2016 +0300
Committer: Vladimir Kotikov <v-...@microsoft.com>
Committed: Mon Aug 8 10:46:02 2016 +0300

----------------------------------------------------------------------
 cordova-lib/spec-cordova/emulate.spec.js | 24 ++++++++++++++++++++++
 cordova-lib/spec-cordova/run.spec.js     | 25 +++++++++++++++++++++++
 cordova-lib/src/cordova/emulate.js       | 29 ++++++++++++++-------------
 cordova-lib/src/cordova/run.js           | 29 ++++++++++++++-------------
 4 files changed, 79 insertions(+), 28 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cordova-lib/blob/9b023d1b/cordova-lib/spec-cordova/emulate.spec.js
----------------------------------------------------------------------
diff --git a/cordova-lib/spec-cordova/emulate.spec.js b/cordova-lib/spec-cordova/emulate.spec.js
index c04c16d..94b2ab9 100644
--- a/cordova-lib/spec-cordova/emulate.spec.js
+++ b/cordova-lib/spec-cordova/emulate.spec.js
@@ -131,6 +131,30 @@ describe('emulate command', function() {
                 }).fin(done);
             });
         });
+
+        it('should call platform\'s build method', function (done) {
+            cordova.raw.emulate({platforms: ['blackberry10']})
+            .then(function() {
+                expect(prepare_spy).toHaveBeenCalled();
+                expect(platformApi.build).toHaveBeenCalledWith({device: false, emulator: true});
+                expect(platformApi.run).toHaveBeenCalledWith(jasmine.objectContaining({nobuild: true}));
+            }, function(err) {
+                expect(err).toBeUndefined();
+            })
+            .fin(done);
+        });
+
+        it('should not call build if --nobuild option is passed', function (done) {
+            cordova.raw.emulate({platforms: ['blackberry10'], options: { nobuild: true }})
+            .then(function() {
+                expect(prepare_spy).toHaveBeenCalled();
+                expect(platformApi.build).not.toHaveBeenCalled();
+                expect(platformApi.run).toHaveBeenCalledWith(jasmine.objectContaining({nobuild: true}));
+            }, function(err) {
+                expect(err).toBeUndefined();
+            })
+            .fin(done);
+        });
     });
 
     describe('hooks', function() {

http://git-wip-us.apache.org/repos/asf/cordova-lib/blob/9b023d1b/cordova-lib/spec-cordova/run.spec.js
----------------------------------------------------------------------
diff --git a/cordova-lib/spec-cordova/run.spec.js b/cordova-lib/spec-cordova/run.spec.js
index b1dedd3..2b09e04 100644
--- a/cordova-lib/spec-cordova/run.spec.js
+++ b/cordova-lib/spec-cordova/run.spec.js
@@ -107,6 +107,31 @@ describe('run command', function() {
                 done();
             });
         });
+
+        it('should call platform\'s build method', function (done) {
+            cordova.raw.run({platforms: ['blackberry10']})
+            .then(function() {
+                expect(prepare_spy).toHaveBeenCalled();
+                expect(platformApi.build).toHaveBeenCalledWith({});
+                expect(platformApi.run).toHaveBeenCalledWith(jasmine.objectContaining({nobuild: true}));
+            }, function(err) {
+                expect(err).toBeUndefined();
+            })
+            .fin(done);
+        });
+
+        it('should not call build if --nobuild option is passed', function (done) {
+            cordova.raw.run({platforms: ['blackberry10'], options: { nobuild: true }})
+            .then(function() {
+                expect(prepare_spy).toHaveBeenCalled();
+                expect(platformApi.build).not.toHaveBeenCalled();
+                expect(platformApi.run).toHaveBeenCalledWith(jasmine.objectContaining({nobuild: true}));
+            }, function(err) {
+                expect(err).toBeUndefined();
+            })
+            .fin(done);
+        });
+
         describe('run parameters should not be altered by intermediate build command', function() {
             var originalBuildSpy;
             beforeEach(function() {

http://git-wip-us.apache.org/repos/asf/cordova-lib/blob/9b023d1b/cordova-lib/src/cordova/emulate.js
----------------------------------------------------------------------
diff --git a/cordova-lib/src/cordova/emulate.js b/cordova-lib/src/cordova/emulate.js
index 642e55c..fdb0f13 100644
--- a/cordova-lib/src/cordova/emulate.js
+++ b/cordova-lib/src/cordova/emulate.js
@@ -32,6 +32,10 @@ module.exports = function emulate(options) {
         options.options.device = false;
         options.options.emulator = true;
 
+        var optsClone = _.clone(options.options);
+        // This is needed as .build modifies opts
+        optsClone.nobuild = true;
+
         var hooksRunner = new HooksRunner(projectRoot);
         return hooksRunner.fire('before_emulate', options)
         .then(function() {
@@ -42,20 +46,17 @@ module.exports = function emulate(options) {
         }).then(function() {
             // Deploy in parallel (output gets intermixed though...)
             return Q.all(options.platforms.map(function(platform) {
-                // This is needed as .build modifies opts
-                var optsClone = _.clone(options.options);
-                return platform_lib
-                    .getPlatformApi(platform)
-                    .build(options.options)
-                    .then(function() {
-                        return hooksRunner.fire('before_deploy', options);
-                    })
-                    .then(function() {
-                        optsClone.nobuild = true;
-                        return platform_lib
-                            .getPlatformApi(platform)
-                            .run(optsClone);
-                    });
+
+                var buildPromise = options.options.nobuild ? Q() :
+                    platform_lib.getPlatformApi(platform).build(options.options);
+
+                return buildPromise
+                .then(function() {
+                    return hooksRunner.fire('before_deploy', options);
+                })
+                .then(function() {
+                    return platform_lib.getPlatformApi(platform).run(optsClone);
+                });
             }));
         }).then(function() {
             return hooksRunner.fire('after_emulate', options);

http://git-wip-us.apache.org/repos/asf/cordova-lib/blob/9b023d1b/cordova-lib/src/cordova/run.js
----------------------------------------------------------------------
diff --git a/cordova-lib/src/cordova/run.js b/cordova-lib/src/cordova/run.js
index 74fe8f5..34a76da 100644
--- a/cordova-lib/src/cordova/run.js
+++ b/cordova-lib/src/cordova/run.js
@@ -30,6 +30,10 @@ module.exports = function run(options) {
         var projectRoot = cordova_util.cdProjectRoot();
         options = cordova_util.preProcessOptions(options);
 
+        // This is needed as .build modifies opts
+        var optsClone = _.clone(options.options);
+        optsClone.nobuild = true;
+
         var hooksRunner = new HooksRunner(projectRoot);
         return hooksRunner.fire('before_run', options)
         .then(function() {
@@ -40,20 +44,17 @@ module.exports = function run(options) {
         }).then(function() {
             // Deploy in parallel (output gets intermixed though...)
             return Q.all(options.platforms.map(function(platform) {
-                // This is needed as .build modifies opts
-                var optsClone = _.clone(options.options);
-                return platform_lib
-                    .getPlatformApi(platform)
-                    .build(options.options)
-                    .then(function() {
-                        return hooksRunner.fire('before_deploy', options);
-                    })
-                    .then(function() {
-                        optsClone.nobuild = true;
-                        return platform_lib
-                            .getPlatformApi(platform)
-                            .run(optsClone);
-                    });
+
+                var buildPromise = options.options.nobuild ? Q() :
+                    platform_lib.getPlatformApi(platform).build(options.options);
+
+                return buildPromise
+                .then(function() {
+                    return hooksRunner.fire('before_deploy', options);
+                })
+                .then(function() {
+                    return platform_lib.getPlatformApi(platform).run(optsClone);
+                });
             }));
         }).then(function() {
             return hooksRunner.fire('after_run', options);


---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@cordova.apache.org
For additional commands, e-mail: commits-help@cordova.apache.org


[2/6] cordova-lib git commit: CB-11205 Respect saved variables when installing plugin

Posted by an...@apache.org.
CB-11205 Respect saved variables when installing plugin

This closes #471


Project: http://git-wip-us.apache.org/repos/asf/cordova-lib/repo
Commit: http://git-wip-us.apache.org/repos/asf/cordova-lib/commit/b5dc35ba
Tree: http://git-wip-us.apache.org/repos/asf/cordova-lib/tree/b5dc35ba
Diff: http://git-wip-us.apache.org/repos/asf/cordova-lib/diff/b5dc35ba

Branch: refs/heads/6.3.x
Commit: b5dc35bac1ac0391237c04bcb76a34fe82607d64
Parents: 6342022
Author: Nikita Matrosov <ni...@rp.ru>
Authored: Fri Jul 29 14:47:44 2016 +0300
Committer: Vladimir Kotikov <v-...@microsoft.com>
Committed: Mon Aug 8 10:45:28 2016 +0300

----------------------------------------------------------------------
 cordova-lib/spec-cordova/save.spec.js | 27 +++++++++++++++++++++++++++
 cordova-lib/src/cordova/plugin.js     |  6 ++++++
 2 files changed, 33 insertions(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cordova-lib/blob/b5dc35ba/cordova-lib/spec-cordova/save.spec.js
----------------------------------------------------------------------
diff --git a/cordova-lib/spec-cordova/save.spec.js b/cordova-lib/spec-cordova/save.spec.js
index e2be5a5..b5ece83 100644
--- a/cordova-lib/spec-cordova/save.spec.js
+++ b/cordova-lib/spec-cordova/save.spec.js
@@ -412,6 +412,33 @@ describe('(save flag)', function () {
             });
         }, TIMEOUT);
 
+        it('spec.14.1 should restore plugin with variables', function (done) {
+            platform('add', platformLocalPathNewer)
+            .then(function () {
+                return cordova.raw.plugin('add', variablePluginUrl, {
+                    'save': true,
+                    'cli_variables': {
+                        'APP_ID':'123456789',
+                        'APP_NAME':'myApplication'
+                    }
+                });
+            }).then(function () {
+                expect(helpers.getPluginVariable(appPath, variablePluginName, 'APP_ID')).toBe('123456789');
+                expect(helpers.getPluginVariable(appPath, variablePluginName, 'APP_NAME')).toBe('myApplication');
+                return cordova.raw.plugin('rm', variablePluginName);
+            }).then(function() {
+                expect(path.join(appPath, 'plugins', variablePluginName)).not.toExist();
+                return cordova.raw.plugin('add', variablePluginName);
+            }).then(function() {
+                expect(path.join(appPath, 'plugins', variablePluginName)).toExist();
+                done();
+            }).catch(function (err) {
+                console.log(err.message);
+                expect(true).toBe(false);
+                done();
+            });
+        }, TIMEOUT);
+
         it('spec.15 save git url as spec', function (done) {
             platform('add', platformLocalPathNewer)
             .then(function () {

http://git-wip-us.apache.org/repos/asf/cordova-lib/blob/b5dc35ba/cordova-lib/src/cordova/plugin.js
----------------------------------------------------------------------
diff --git a/cordova-lib/src/cordova/plugin.js b/cordova-lib/src/cordova/plugin.js
index e8d6acb..d803425 100644
--- a/cordova-lib/src/cordova/plugin.js
+++ b/cordova-lib/src/cordova/plugin.js
@@ -155,6 +155,12 @@ module.exports = function plugin(command, targets, opts) {
                         .then(function(pluginInfo) {
                             // Validate top-level required variables
                             var pluginVariables = pluginInfo.getPreferences();
+                            opts.cli_variables = opts.cli_variables || {};                          
+                            var pluginEntry = cfg.getPlugin(pluginInfo.id);                           
+                            var pluginEntryVariables = pluginEntry ? pluginEntry.variables : {};                                                 
+                            Object.keys(pluginVariables).forEach(function(varName) {
+                                opts.cli_variables[varName] = opts.cli_variables[varName] || pluginEntryVariables[varName];
+                            });                
                             var missingVariables = Object.keys(pluginVariables)
                             .filter(function (variableName) {
                                 // discard variables with default value


---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@cordova.apache.org
For additional commands, e-mail: commits-help@cordova.apache.org


[6/6] cordova-lib git commit: CB-11685 Updated version and RELEASENOTES.md for 6.3.1 release

Posted by an...@apache.org.
CB-11685 Updated version and RELEASENOTES.md for 6.3.1 release


Project: http://git-wip-us.apache.org/repos/asf/cordova-lib/repo
Commit: http://git-wip-us.apache.org/repos/asf/cordova-lib/commit/a2736f59
Tree: http://git-wip-us.apache.org/repos/asf/cordova-lib/tree/a2736f59
Diff: http://git-wip-us.apache.org/repos/asf/cordova-lib/diff/a2736f59

Branch: refs/heads/6.3.x
Commit: a2736f594c47c0ecb173ea7f17d9ffa18758752a
Parents: 9b023d1
Author: Vladimir Kotikov <v-...@microsoft.com>
Authored: Mon Aug 8 10:55:36 2016 +0300
Committer: Vladimir Kotikov <v-...@microsoft.com>
Committed: Tue Aug 9 10:43:20 2016 +0300

----------------------------------------------------------------------
 cordova-lib/RELEASENOTES.md | 7 +++++++
 cordova-lib/package.json    | 2 +-
 2 files changed, 8 insertions(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cordova-lib/blob/a2736f59/cordova-lib/RELEASENOTES.md
----------------------------------------------------------------------
diff --git a/cordova-lib/RELEASENOTES.md b/cordova-lib/RELEASENOTES.md
index dc3f77d..95179ba 100644
--- a/cordova-lib/RELEASENOTES.md
+++ b/cordova-lib/RELEASENOTES.md
@@ -20,6 +20,13 @@
 -->
 # Cordova-lib Release Notes
 
+### 6.3.1 (Aug 08, 2016)
+* [CB-11652](https://issues.apache.org/jira/browse/CB-11652) Update run and emulate to skip build
+* [CB-11194](https://issues.apache.org/jira/browse/CB-11194) Defer creating of libDir folder until something actually requests it
+* [CB-11493](https://issues.apache.org/jira/browse/CB-11493) Add cordova emulate option to skip prepare
+* [CB-11205](https://issues.apache.org/jira/browse/CB-11205) Respect saved variables when installing plugin
+* [CB-11589](https://issues.apache.org/jira/browse/CB-11589) Fix missing plugin files after restore
+
 ### 6.3.0 (Jul 12, 2016)
 * [CB-11491](https://issues.apache.org/jira/browse/CB-11491) Introduce before_deploy hook
 * [CB-11412](https://issues.apache.org/jira/browse/CB-11412) template support for www folders

http://git-wip-us.apache.org/repos/asf/cordova-lib/blob/a2736f59/cordova-lib/package.json
----------------------------------------------------------------------
diff --git a/cordova-lib/package.json b/cordova-lib/package.json
index c5d89e3..c39b18b 100644
--- a/cordova-lib/package.json
+++ b/cordova-lib/package.json
@@ -2,7 +2,7 @@
   "author": "Apache Software Foundation",
   "name": "cordova-lib",
   "description": "Apache Cordova tools core lib and API",
-  "version": "6.3.0",
+  "version": "6.3.1",
   "repository": {
     "type": "git",
     "url": "git://git-wip-us.apache.org/repos/asf/cordova-lib.git"


---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@cordova.apache.org
For additional commands, e-mail: commits-help@cordova.apache.org
diff --git a/cordova-lib/src/cordova/platform.js b/cordova-lib/src/cordova/platform.js
index 95f1af5..680fb3b 100644
--- a/cordova-lib/src/cordova/platform.js
+++ b/cordova-lib/src/cordova/platform.js
@@ -193,22 +193,26 @@ function addHelper(cmd, hooksRunner, projectRoot, targets, opts) {
 
                 return promise()
                 .then(function () {
-                    return prepare.preparePlatforms([platform], projectRoot, { searchpath: opts.searchpath });
+                    if (!opts.restoring) {
+                        return prepare.preparePlatforms([platform], projectRoot, { searchpath: opts.searchpath });
+                    }
                 })
                 .then(function() {
-                    if (cmd == 'add') {
+                    if (cmd == 'add' && !opts.restoring) {
                         return installPluginsForNewPlatform(platform, projectRoot, opts);
                     }
                 })
                 .then(function () {
-                    // Call prepare for the current platform.
-                    var prepOpts = {
-                        platforms :[platform],
-                        searchpath :opts.searchpath,
-                        fetch: opts.fetch || false,
-                        save: opts.save || false
-                    };
-                    return require('./cordova').raw.prepare(prepOpts);
+                    if (!opts.restoring) {
+                        // Call prepare for the current platform if we're not restoring from config.xml
+                        var prepOpts = {
+                            platforms :[platform],
+                            searchpath :opts.searchpath,
+                            fetch: opts.fetch || false,
+                            save: opts.save || false
+                        };
+                        return require('./cordova').raw.prepare(prepOpts);
+                    }
                 })
                 .then(function() {
                     var saveVersion = !spec || semver.validRange(spec, true);

http://git-wip-us.apache.org/repos/asf/cordova-lib/blob/63420225/cordova-lib/src/cordova/prepare.js
----------------------------------------------------------------------